<template>
  <ModalDialog
    ref="createModal"
    is-page
    @close="$router.push({ name: 'admin.users' })"
  >
    <ModalHeader>
      <ModalTitle>{{ $t("app.admin.users.create.title") }}</ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <FormInput
          id="name"
          :errors="form.errors.name"
        >
          <FormLabel>{{ $t("app.admin.users.form.name") }}</FormLabel>
          <FormText
            v-model="form.values.name"
            autocomplete="off"
            name="name"
            required
          />
        </FormInput>
        <FormInput
          id="email"
          :errors="form.errors.email"
        >
          <FormLabel>{{ $t("app.admin.users.form.email") }}</FormLabel>
          <FormText
            v-model="form.values.email"
            autocomplete="off"
            name="email"
            required
            type="email"
          />
        </FormInput>
        <FormInput
          id="password"
          :errors="form.errors.password"
        >
          <FormLabel>{{ $t("app.admin.users.form.password") }}</FormLabel>
          <FormText
            v-model="form.values.password"
            autocomplete="off"
            name="password"
            required
            type="password"
          />
        </FormInput>
        <FormInput
          id="user_role_id"
          :errors="form.errors.user_role_id"
        >
          <FormLabel>{{ $t("app.admin.users.form.user_role_id") }}</FormLabel>
          <UserRoleSelect
            v-model="form.values.user_role_id"
            required
          />
        </FormInput>
      </template>
      <template #footer>
        <FormSubmit
          class="btn btn-black"
          :processing="form.isFetching"
        >
          {{ $t("app.admin.users.create.submit") }}
        </FormSubmit>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script lang="ts" setup>
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import type { UserCreate } from "@/js/contexts/shared/models/User";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import UserRoleSelect from "@/js/contexts/admin/user-roles/ui/components/UserRoleSelect.vue";
import useModal from "@/js/contexts/shared/composables/useModal";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const emit = defineEmits<{
  fetch: [];
}>();

const { t } = useI18n();
const { successNotification } = useNotification();
const createModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(createModal);
const form = useForm<UserCreate>({
  name: "",
  email: "",
  password: "",
  user_role_id: null,
});

const submit = () => {
  form.post("/api/admin/users", {
    onSuccess: () => {
      emit("fetch");
      modal.close();
      successNotification(t("app.admin.users.create.success"));
    },
  });
};
</script>
